'use strict';

var _createClass = require('babel-runtime/helpers/create-class')['default'];

var _classCallCheck = require('babel-runtime/helpers/class-call-check')['default'];

var _regeneratorRuntime = require('babel-runtime/regenerator')['default'];

var _Promise = require('babel-runtime/core-js/promise')['default'];

var _interopRequireDefault = require('babel-runtime/helpers/interop-require-default')['default'];

Object.defineProperty(exports, '__esModule', {
	value: true
});

var _promptsJs = require('./prompts.js');

var _objectAssign = require('object-assign');

var _objectAssign2 = _interopRequireDefault(_objectAssign);

var _convertSeconds = require('convert-seconds');

var _convertSeconds2 = _interopRequireDefault(_convertSeconds);

var _validFile = require('valid-file');

var _validFile2 = _interopRequireDefault(_validFile);

var _inquirer = require('inquirer');

var _inquirer2 = _interopRequireDefault(_inquirer);

var _pendel = require('pendel');

var _pendel2 = _interopRequireDefault(_pendel);

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

// help node 0.10 with Promises
require('native-promise-only');

var TimeCard = (function () {
	/**
  * Initilize a new Timecard
  *
  * @param {Object} options
  * @api public
  */

	function TimeCard(options) {
		_classCallCheck(this, TimeCard);

		this.options = (0, _objectAssign2['default'])({}, options);

		this.filepath = this.options.filepath ? _path2['default'].join(this.options.filepath, '.timecard.json') : _path2['default'].join(__dirname, '.timecard.json');
		this.name = process.cwd().split(_path2['default'].sep).pop();
		this.prompt = this.options.prompt;
		this.clockoutIsPending = false;
		this.pendingClockoutIndex = null;
		this.totalSeconds = 0;
		this.timecardData = null;
		this.shifts = [];
	}

	/**
  * Create a blank timecard on `timecard new`
  *
  */

	_createClass(TimeCard, [{
		key: 'create',
		value: function create() {
			var self;
			return _regeneratorRuntime.async(function create$(context$2$0) {
				while (1) switch (context$2$0.prev = context$2$0.next) {
					case 0:
						self = this;
						return context$2$0.abrupt('return', new _Promise(function (resolve) {
							if (self.prompt) {
								var questions = (0, _promptsJs.createPrompt)();

								// First check to see if the file already exists
								if (_validFile2['default'].sync(self.filepath)) {
									questions = (0, _promptsJs.eraseThenCreatePrompt)();
								}

								_inquirer2['default'].prompt(questions, function (answers) {
									if (answers.eraseCard === false) {
										process.exit();
									} else {
										self.writeTimeCard(self.blankTimecard(answers.projectName)).then(function () {
											self.reportSuccessfulNewTimeCard();
											resolve(self);
										});
									}
								});
							} else {
								self.writeTimeCard(self.blankTimecard(self.name)).then(function () {
									self.reportSuccessfulNewTimeCard();
									resolve(self);
								});
							}
						}));

					case 2:
					case 'end':
						return context$2$0.stop();
				}
			}, null, this);
		}

		/**
   * Clockin.
   *
   */

	}, {
		key: 'clockin',
		value: function clockin() {
			var self;
			return _regeneratorRuntime.async(function clockin$(context$2$0) {
				var _this = this;

				while (1) switch (context$2$0.prev = context$2$0.next) {
					case 0:
						self = this;

						if (_validFile2['default'].sync(self.filepath) === false) {
							console.log(self.errors.noTimeCardFoundForClockin);
							process.exit(1);
						}

						return context$2$0.abrupt('return', new _Promise(function callee$2$0(resolve) {
							var date, tc;
							return _regeneratorRuntime.async(function callee$2$0$(context$3$0) {
								while (1) switch (context$3$0.prev = context$3$0.next) {
									case 0:
										context$3$0.next = 2;
										return _regeneratorRuntime.awrap(self.getTimeCardData());

									case 2:

										if (self.clockoutIsPending) {
											console.log(self.errors.clockOutIsPending);
											process.exit(0);
										}
										date = new Date().toString();
										tc = {
											id: self.shifts.length,
											date: date.slice(0, 15),
											startTime: date.slice(16, 24)
										};

										self.timecardData.shifts.push(tc);

										self.writeTimeCard(JSON.stringify(self.timecardData, null, 2)).then(function () {
											self.reportSuccessfulClockIn();
											resolve(self);
										});

									case 7:
									case 'end':
										return context$3$0.stop();
								}
							}, null, _this);
						}));

					case 3:
					case 'end':
						return context$2$0.stop();
				}
			}, null, this);
		}

		/**
   * Clockout.
   *
   */

	}, {
		key: 'clockout',
		value: function clockout() {
			var self;
			return _regeneratorRuntime.async(function clockout$(context$2$0) {
				var _this2 = this;

				while (1) switch (context$2$0.prev = context$2$0.next) {
					case 0:
						self = this;

						if (_validFile2['default'].sync(self.filepath) === false) {
							console.log(self.errors.noTimeCardFoundForClockout);
							process.exit(1);
						}

						return context$2$0.abrupt('return', new _Promise(function callee$2$0(resolve) {
							var date, shiftSeconds;
							return _regeneratorRuntime.async(function callee$2$0$(context$3$0) {
								while (1) switch (context$3$0.prev = context$3$0.next) {
									case 0:
										context$3$0.next = 2;
										return _regeneratorRuntime.awrap(self.getTimeCardData());

									case 2:

										if (self.clockoutIsPending) {
											date = new Date().toString();

											self.shifts[self.pendingClockoutIndex].endTime = date.slice(16, 24);

											// report the last 'shift' time and the total time to the console.
											shiftSeconds = (0, _pendel2['default'])(self.shifts[self.pendingClockoutIndex].startTime, self.shifts[self.pendingClockoutIndex].endTime).seconds;

											console.log(self.clockoutSummary(shiftSeconds, self.totalSeconds + shiftSeconds));

											self.totalSeconds += shiftSeconds;
											self.timecardData.totals = (0, _convertSeconds2['default'])(self.totalSeconds);

											self.writeTimeCard(JSON.stringify(self.timecardData, null, 2)).then(function () {
												self.reportSuccessfulClockOut();
												resolve(self);
											});
										} else {
											console.log(self.errors.noClockInFound);
											process.exit(0);
										}

									case 3:
									case 'end':
										return context$3$0.stop();
								}
							}, null, _this2);
						}));

					case 3:
					case 'end':
						return context$2$0.stop();
				}
			}, null, this);
		}

		/**
   * Print the timecard data to the console.
   *
   */

	}, {
		key: 'printTimecard',
		value: function printTimecard() {
			var self;
			return _regeneratorRuntime.async(function printTimecard$(context$2$0) {
				var _this3 = this;

				while (1) switch (context$2$0.prev = context$2$0.next) {
					case 0:
						self = this;
						return context$2$0.abrupt('return', new _Promise(function callee$2$0(resolve) {
							var output;
							return _regeneratorRuntime.async(function callee$2$0$(context$3$0) {
								while (1) switch (context$3$0.prev = context$3$0.next) {
									case 0:
										context$3$0.next = 2;
										return _regeneratorRuntime.awrap(self.getTimeCardData());

									case 2:
										output = self.prettyPrintHeader();

										self.timecardData.shifts.map(function (item) {
											output += self.prettyPrintEntry(item);
										});
										output += self.messages.prettyPrintBorder;
										output += self.summary(self.totalSeconds);
										console.log(output);
										resolve(output);

									case 8:
									case 'end':
										return context$3$0.stop();
								}
							}, null, _this3);
						}));

					case 2:
					case 'end':
						return context$2$0.stop();
				}
			}, null, this);
		}
	}]);

	return TimeCard;
})();

exports['default'] = TimeCard;

(0, _objectAssign2['default'])(TimeCard.prototype, require('./utils.js'));
(0, _objectAssign2['default'])(TimeCard.prototype, require('./messages.js'));
module.exports = exports['default'];